window.Gleam.initSearch([{"doc":"integer_complexity","title":"integer_complexity","content":"# integer_complexity\n\n[![Package Version](https://img.shields.io/hexpm/v/integer_complexity)](https://hex.pm/packages/integer_complexity)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/integer_complexity/)\n\nA library for computing integer complexity.\n\n&quot;The complexity of an integer n is the least number of 1&#39;s needed to represent it using only additions, multiplications and parentheses.&quot; (&lt;https://oeis.org/A005245&gt;)\n\nBased on &quot;Algorithms for determining integer complexity&quot; by J. Arias de Reyna and J. van de Lune\n&lt;https://arxiv.org/abs/1404.2183&gt;.\n\n## Installation\n\nAdd `integer_complexity` to your Gleam project.\n\n```sh\ngleam add integer_complexity\n```\n\n## Examples\n\n\n```gleam\nimport integer_complexity\nimport integer_complexity/expression\n\npub fn main() {\n  use cache &lt;- integer_complexity.new_cache()\n\n  let complexity_of_ten =\n    integer_complexity.get_complexity(cache, 10)\n  //complexity_of_ten = 7\n\n  let complexity_expression_of_ten =\n    integer_complexity.get_expression(cache, 10)\n  //complexity_expression_of_ten = \n  //  Multiply(Add(One, One), Add(Multiply(Add(One, One), Add(One, One)), One))\n\n  let string =\n    expression.to_string(expression, expression.default_format_options())\n  //string = (1 + 1) * ((1 + 1) * (1 + 1) + 1)\n\n  let base_five_options = \n    expression.default_format_options()\n    |&gt; expression.with_digits([&quot;1&quot;, &quot;2&quot;, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;])\n\n\n  let string_base_five =\n    expression.to_string(expression, base_five_options)\n  //string_base_five = 2 * 5\n}\n```\n\n## Targets\n\nThe Erlang and JavaScript targets are both supported.\n","url":"index.html"},{"doc":"integer_complexity/expression","title":"Expression","content":"pub type Expression {\n  Add(lhs: Expression, rhs: Expression)\n  Multiply(lhs: Expression, rhs: Expression)\n  One\n}\n A tree representing an expression.\nAdd(lhs: Expression, rhs: Expression)\n\n\nMultiply(lhs: Expression, rhs: Expression)\n\n\nOne\n\n\nSynonyms:\ninteger_complexity/expression.Expression\ninteger_complexity/expression Expression","url":"integer_complexity/expression.html#Expression"},{"doc":"integer_complexity/expression","title":"FormatOptions","content":"pub opaque type FormatOptions(\n  padding_defined,\n  add_defined,\n  multiply_defined,\n  left_paren_defined,\n  right_paren_defined,\n  digits_defined,\n)\n Formatting options for `expression.to_string`\n\nSynonyms:\ninteger_complexity/expression.FormatOptions\ninteger_complexity/expression FormatOptions","url":"integer_complexity/expression.html#FormatOptions"},{"doc":"integer_complexity/expression","title":"default_format_options","content":"pub fn default_format_options() -&gt; FormatOptions(a, b, c, d, e, f)\n Returns preset formatting options for `expression.to_string`.\nSynonyms:\ninteger_complexity/expression.default_format_options\ninteger_complexity/expression default_format_options","url":"integer_complexity/expression.html#default_format_options"},{"doc":"integer_complexity/expression","title":"evaluate_expression","content":"pub fn evaluate_expression(expression: Expression) -&gt; Int\n Evaluate an expression.\nSynonyms:\ninteger_complexity/expression.evaluate_expression\ninteger_complexity/expression evaluate_expression","url":"integer_complexity/expression.html#evaluate_expression"},{"doc":"integer_complexity/expression","title":"to_string","content":"pub fn to_string(\n  expression: Expression,\n  options: FormatOptions(a, b, c, d, e, f),\n) -&gt; String\n Convert an `Expression` to a string with the specified formatting options.\nSynonyms:\ninteger_complexity/expression.to_string\ninteger_complexity/expression to_string","url":"integer_complexity/expression.html#to_string"},{"doc":"integer_complexity/expression","title":"with_addition_sign","content":"pub fn with_addition_sign(\n  options: FormatOptions(a, AddSignNotDefined, b, c, d, e),\n  sign: String,\n) -&gt; FormatOptions(a, AddSignDefined, b, c, d, e)\n Specifies the string to use for the addition sign. default: `&quot;+&quot;`\nSynonyms:\ninteger_complexity/expression.with_addition_sign\ninteger_complexity/expression with_addition_sign","url":"integer_complexity/expression.html#with_addition_sign"},{"doc":"integer_complexity/expression","title":"with_digits","content":"pub fn with_digits(\n  options: FormatOptions(a, b, c, d, e, DigitsNotDefined),\n  digits: List(String),\n) -&gt; FormatOptions(a, b, c, d, e, DigitsDefined)\n Specifies the digits to use. Digits must be ordered from least to greatest. \n The (Bijective) base that will be used will be the length of the array.\n default: `[&quot;1&quot;]`\nSynonyms:\ninteger_complexity/expression.with_digits\ninteger_complexity/expression with_digits","url":"integer_complexity/expression.html#with_digits"},{"doc":"integer_complexity/expression","title":"with_left_bracket","content":"pub fn with_left_bracket(\n  options: FormatOptions(a, b, c, LeftBracketNotDefined, d, e),\n  left_bracket: String,\n) -&gt; FormatOptions(a, b, c, LeftBracketDefined, d, e)\n Specifies the string to use for the left bracket. default: `&quot;(&quot;`\nSynonyms:\ninteger_complexity/expression.with_left_bracket\ninteger_complexity/expression with_left_bracket","url":"integer_complexity/expression.html#with_left_bracket"},{"doc":"integer_complexity/expression","title":"with_multiplication_sign","content":"pub fn with_multiplication_sign(\n  options: FormatOptions(a, b, MultiplySignNotDefined, c, d, e),\n  sign: String,\n) -&gt; FormatOptions(a, b, MultiplySignDefined, c, d, e)\n Specifies the string to use for the multiplication sign. default: `&quot;*&quot;`\nSynonyms:\ninteger_complexity/expression.with_multiplication_sign\ninteger_complexity/expression with_multiplication_sign","url":"integer_complexity/expression.html#with_multiplication_sign"},{"doc":"integer_complexity/expression","title":"with_padding","content":"pub fn with_padding(\n  options: FormatOptions(PaddingNotDefined, a, b, c, d, e),\n  padding: String,\n) -&gt; FormatOptions(PaddingDefined, a, b, c, d, e)\n Specifies the string to use for padding (spaces). default: `&quot; &quot;`\nSynonyms:\ninteger_complexity/expression.with_padding\ninteger_complexity/expression with_padding","url":"integer_complexity/expression.html#with_padding"},{"doc":"integer_complexity/expression","title":"with_right_bracket","content":"pub fn with_right_bracket(\n  options: FormatOptions(a, b, c, d, RightBracketNotDefined, e),\n  right_bracket: String,\n) -&gt; FormatOptions(a, b, c, d, RightBracketDefined, e)\n Specifies the string to use for the right bracket. default: `&quot;)&quot;`\nSynonyms:\ninteger_complexity/expression.with_right_bracket\ninteger_complexity/expression with_right_bracket","url":"integer_complexity/expression.html#with_right_bracket"},{"doc":"integer_complexity/expression","title":"integer_complexity/expression","content":"","url":"integer_complexity/expression.html"},{"doc":"integer_complexity","title":"new_cache","content":"pub const new_cache: fn(fn(Set(a, b)) -&gt; c) -&gt; c\n Create a new cache used to store computed integer complexities.\nSynonyms:\ninteger_complexity.new_cache\ninteger_complexity new_cache","url":"integer_complexity.html#new_cache"},{"doc":"integer_complexity","title":"get_complexities_up_to","content":"pub fn get_complexities_up_to(\n  cache: Set(Int, ComplexityData),\n  integer: Int,\n) -&gt; Result(List(Int), Nil)\n Returns a list of integer complexities from 1 up to the specified integer. \n Returns `Error(Nil)` if the specified integer is less than 1.\nSynonyms:\ninteger_complexity.get_complexities_up_to\ninteger_complexity get_complexities_up_to","url":"integer_complexity.html#get_complexities_up_to"},{"doc":"integer_complexity","title":"get_complexity","content":"pub fn get_complexity(\n  cache cache: Set(Int, ComplexityData),\n  of integer: Int,\n) -&gt; Int\n Returns the integer complexity of the (absoulte value of the) specified integer.\nSynonyms:\ninteger_complexity.get_complexity\ninteger_complexity get_complexity","url":"integer_complexity.html#get_complexity"},{"doc":"integer_complexity","title":"get_expression","content":"pub fn get_expression(\n  cache cache: Set(Int, ComplexityData),\n  of integer: Int,\n) -&gt; Result(Expression, Nil)\n Returns a valid expression following the rules of integer complexity of the (absoulte value of the) specified integer.\n Note that there can be multiple valid expressions for an integer, but this function only\n generates a single expression. \n Returns `Error(Nil)` if the specified integer is `0`.\nSynonyms:\ninteger_complexity.get_expression\ninteger_complexity get_expression","url":"integer_complexity.html#get_expression"},{"doc":"integer_complexity","title":"get_expressions_up_to","content":"pub fn get_expressions_up_to(\n  cache: Set(Int, ComplexityData),\n  integer: Int,\n) -&gt; Result(List(Expression), Nil)\n Returns a list of integer complexity expressins (one per integer) from 1 up to the specified integer.\n Returns `Error(Nil)` if the specified integer is less than 1.\nSynonyms:\ninteger_complexity.get_expressions_up_to\ninteger_complexity get_expressions_up_to","url":"integer_complexity.html#get_expressions_up_to"},{"doc":"integer_complexity","title":"integer_complexity","content":" This module contains functions for computing the complexity of an integer, \n and a corrisponding mathematical expression that uses only ones, addition, and multiplication to reach that integer.\n testing the products","url":"integer_complexity.html"}]);